==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Test/Gui/Resources/translations/Test_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="eu" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="16"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="31"/>
      <source>Failures and errors</source>
      <translation>Hutsegiteak eta erroreak</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="47"/>
      <source>Description</source>
      <translation>Deskribapena</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="82"/>
      <source>&amp;Start</source>
      <translation>H&amp;asi</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="85"/>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="114"/>
      <source>&amp;Help</source>
      <translation>L&amp;aguntza</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="117"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="127"/>
      <source>&amp;About</source>
      <translation>&amp;Honi buruz</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="130"/>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="140"/>
      <source>&amp;Close</source>
      <translation>&amp;Itxi</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="143"/>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="161"/>
      <source>Idle</source>
      <translation>Inaktibo</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="168"/>
      <source>Progress</source>
      <translation>Aurrerapena</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="197"/>
      <source>Remaining:</source>
      <translation>Gelditzen da:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="214"/>
      <source>Errors:</source>
      <translation>Erroreak:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="231"/>
      <source>Failures:</source>
      <translation>Hutsegiteak:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="248"/>
      <source>Run:</source>
      <translation>Exekutatu:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="258"/>
      <source>Test</source>
      <translation>Proba</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="270"/>
      <source>Select test name:</source>
      <translation>Hautatu probaren izena:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="162"/>
      <source>Help</source>
      <translation>Laguntza</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="162"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Sartu izendagarria den objektuaren izena. Deitutakoan TestCase bat itzuliko du. Klikatu 'Hasi' eta proba abiatuko da.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="174"/>
      <source>About FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest aplikazioari buruz</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="174"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest aplikazioa FreeCAD aplikazioaren atal bat da eta haren moduluetarako proba-unitateak idaztea onartzen du.</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Test/Gui/Resources/translations/Test_eu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="16"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="31"/>
      <source>Failures and errors</source>
      <translation>Hutsegiteak eta erroreak</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="47"/>
      <source>Description</source>
      <translation>Deskribapena</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="82"/>
      <source>&amp;Start</source>
      <translation>H&amp;asi</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="85"/>
      <source>Alt+S</source>
      <translation>Alt+S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="114"/>
      <source>&amp;Help</source>
      <translation>L&amp;aguntza</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="117"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="127"/>
      <source>&amp;About</source>
      <translation>&amp;Honi buruz</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="130"/>
      <source>Alt+A</source>
      <translation>Alt+A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="140"/>
      <source>&amp;Close</source>
      <translation>&amp;Itxi</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="143"/>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="161"/>
      <source>Idle</source>
      <translation>Inaktibo</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="168"/>
      <source>Progress</source>
      <translation>Aurrerapena</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="197"/>
      <source>Remaining:</source>
      <translation>Gelditzen da:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="214"/>
      <source>Errors:</source>
      <translation>Erroreak:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="231"/>
      <source>Failures:</source>
      <translation>Hutsegiteak:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="248"/>
      <source>Run:</source>
      <translation>Distantzia:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="258"/>
      <source>Test</source>
      <translation>Proba</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="270"/>
      <source>Select test name:</source>
      <translation>Hautatu probaren izena:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>Help</source>
      <translation>Laguntza</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="164"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Sartu izendagarria den objektuaren izena. Deitutakoan TestCase bat itzuliko du. Klikatu 'Hasi' eta proba abiatuko da.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="176"/>
      <source>About FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest aplikazioari buruz</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="176"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest aplikazioa FreeCAD aplikazioaren atal bat da eta haren moduluetarako proba-unitateak idaztea onartzen du.</translation>
    </message>
  </context>
</TS>
